diff --git a/server/notification-providers/google-chat.js b/server/notification-providers/google-chat.js
index c05830d93..b9614d4a9 100644
--- a/server/notification-providers/google-chat.js
+++ b/server/notification-providers/google-chat.js
@@ -80,11 +80,12 @@ class GoogleChat extends NotificationProvider {
});
}
- // add monitor URL if available
- if (monitorJSON && monitorJSON["url"]) {
+ // add monitor address if available
+ const address = this.extractAddress(monitorJSON);
+ if (address) {
sectionWidgets.push({
textParagraph: {
- text: `URL:\n${monitorJSON["url"]}`,
+ text: `Address:\n${address}`,
},
});
}